@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2017 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Datamash.  If not, see <http://www.gnu.org/licenses/>.
+   along with GNU Datamash.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 /* Written by Assaf Gordon */
@@ -97,19 +97,24 @@ static FILE* input_stream = NULL;
 /* Use large buffer for normal operation (will be reduced for testing) */
 static size_t rmdup_initial_size = (1024*1024);
 
+/* Explicit output delimiter with --output-delimiter */
+static int explicit_output_delimiter = -1;
+
 enum
 {
   INPUT_HEADER_OPTION = CHAR_MAX + 1,
   OUTPUT_HEADER_OPTION,
   NO_STRICT_OPTION,
   REMOVE_NA_VALUES_OPTION,
+  OUTPUT_DELIMITER_OPTION,
+  CUSTOM_FORMAT_OPTION,
   UNDOC_PRINT_INF_OPTION,
   UNDOC_PRINT_NAN_OPTION,
   UNDOC_PRINT_PROGNAME_OPTION,
   UNDOC_RMDUP_TEST
 };
 
-static char const short_options[] = "sfF:izg:t:HW";
+static char const short_options[] = "sfF:izg:t:HWR:";
 
 static struct option const long_options[] =
 {
@@ -123,9 +128,12 @@ static struct option const long_options[] =
   {"headers", no_argument, NULL, 'H'},
   {"full", no_argument, NULL, 'f'},
   {"filler", required_argument, NULL, 'F'},
+  {"format", required_argument, NULL, CUSTOM_FORMAT_OPTION},
+  {"output-delimiter", required_argument, NULL, OUTPUT_DELIMITER_OPTION},
   {"sort", no_argument, NULL, 's'},
   {"no-strict", no_argument, NULL, NO_STRICT_OPTION},
   {"narm", no_argument, NULL, REMOVE_NA_VALUES_OPTION},
+  {"round", required_argument, NULL, 'R'},
   {GETOPT_HELP_OPTION_DECL},
   {GETOPT_VERSION_OPTION_DECL},
   /* Undocumented options */
@@ -198,8 +206,9 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
 
       fputs (_("Statistical Grouping operations:\n"),stdout);
       fputs ("\
-  mean, median, q1, q3, iqr, perc, mode, antimode, pstdev, sstdev, pvar,\n\
-  svar, mad, madraw, pskew, sskew, pkurt, skurt, dpo, jarque,\n\
+  mean, trimmean, median, q1, q3, iqr, perc, mode, antimode, \n\
+  pstdev, sstdev, pvar, svar, mad, madraw,\n\
+  pskew, sskew, pkurt, skurt, dpo, jarque,\n\
   scov, pcov, spearson, ppearson\n\
 \n", stdout);
       fputs ("\n", stdout);
@@ -243,9 +252,20 @@ which require a pair of fields (e.g. 'pcov 2:6').\n"), stdout);
       fputs (_("General Options:\n"),stdout);
       fputs (_("\
   -t, --field-separator=X   use X instead of TAB as field delimiter\n\
+"), stdout);
+      fputs (_("\
+      --format=FORMAT       print numeric values with printf style\n\
+                            floating-point FORMAT.\n\
+"), stdout);
+      fputs (_("\
+      --output-delimiter=X  use X instead as output field delimiter\n\
+                            (default: use same delimiter as -t/-W)\n\
 "), stdout);
       fputs (_("\
       --narm                skip NA/NaN values\n\
+"), stdout);
+      fputs (_("\
+  -R, --round=N             round numeric output to N decimal places\n\
 "), stdout);
       fputs (_("\
   -W, --whitespace          use whitespace (one or more spaces and/or tabs)\n\
@@ -449,6 +469,9 @@ print_column_headers ()
       if (op->op == OP_PERCENTILE) {
         printf (":%"PRIuMAX, (uintmax_t)op->params.percentile);
       }
+      if (op->op == OP_TRIMMED_MEAN) {
+        printf (":%Lg", op->params.trimmed_mean);
+      }
 
       printf ("(%s)", get_input_field_name (op->field));
 
@@ -1152,6 +1175,10 @@ int main (int argc, char* argv[])
           input_header = output_header = true;
           break;
 
+	case 'R':
+	  set_numeric_output_precision (optarg);
+	  break;
+
         case 's':
           pipe_through_sort = true;
           break;
@@ -1160,6 +1187,10 @@ int main (int argc, char* argv[])
           strict = false;
           break;
 
+        case CUSTOM_FORMAT_OPTION:
+          set_numeric_printf_format (optarg);
+          break;
+
         case REMOVE_NA_VALUES_OPTION:
           remove_na_values = true;
           break;
@@ -1171,6 +1202,13 @@ int main (int argc, char* argv[])
           in_tab = out_tab = optarg[0];
           break;
 
+	case OUTPUT_DELIMITER_OPTION:
+          if (optarg[0] == '\0' || optarg[1] != '\0')
+            die (EXIT_FAILURE, 0,
+                   _("the delimiter must be a single character"));
+	  explicit_output_delimiter = (char)optarg[0];
+	  break;
+
         case 'W':
           in_tab = TAB_WHITESPACE;
           out_tab = '\t';
@@ -1201,13 +1239,16 @@ int main (int argc, char* argv[])
         }
     }
 
-
   if (argc <= optind)
     {
       error (0, 0, _("missing operation specifiers"));
       usage (EXIT_FAILURE);
     }
 
+  /* If --output-delimiter=X was used, override any previous output delimiter */
+  if (explicit_output_delimiter != -1)
+    out_tab = explicit_output_delimiter ;
+
   /* The rest of the parameters are the operations */
   if (premode == MODE_INVALID)
     dm = datamash_ops_parse (argc - optind, (const char**)argv+optind);
