@@ -1,6 +1,6 @@
 /* GNU Datamash - perform simple calculation on input data
 
-   Copyright (C) 2013-2017 Assaf Gordon <assafgordon@gmail.com>
+   Copyright (C) 2013-2018 Assaf Gordon <assafgordon@gmail.com>
 
    This file is part of GNU Datamash.
 
@@ -15,7 +15,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Datamash.  If not, see <http://www.gnu.org/licenses/>.
+   along with GNU Datamash.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 /* Written by Assaf Gordon */
@@ -42,8 +42,10 @@ extern int out_tab ;
 /* Global case-sensitivity option. Defaults to 'true' . */
 extern bool case_sensitive ;
 
-/* precision used with printf "%.*Lg" */
-extern int numeric_output_precision;
+/* Numeric output format (default: "%.14Lg" */
+extern char* numeric_output_format;
+/* number of bytes to allocate for output buffer */
+extern int   numeric_output_bufsize;
 
 /* The character used to separate collapsed/uniqued strings */
 extern char collapse_separator;
@@ -79,4 +81,11 @@ print_line_separator ()
   putchar (eolchar);
 }
 
+
+void
+set_numeric_output_precision (const char* digits);
+
+void
+set_numeric_printf_format (const char* format);
+
 #endif
